@@ -3,9 +3,8 @@
     Copyright (C) 1997,1998  Matt Kimball
 
     This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    it under the terms of the GNU General Public License version 2 as 
+    published by the Free Software Foundation.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -18,8 +17,8 @@
 */
 
 /*  Prototypes for curses.c  */
-void mtr_curses_open();
-void mtr_curses_close();
-void mtr_curses_redraw();
-int mtr_curses_keyaction();
-void mtr_curses_clear();
+void mtr_curses_open(void);
+void mtr_curses_close(void);
+void mtr_curses_redraw(void);
+int mtr_curses_keyaction(void);
+void mtr_curses_clear(void);
