@@ -5,9 +5,8 @@
     Copyright (C) 1998  Bertrand Leconte <B.Leconte@mail.dotcom.fr>
 
     This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+    it under the terms of the GNU General Public License version 2 as 
+    published by the Free Software Foundation.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,7 +19,7 @@
 */
 
 /*  Prototypes for split.c  */
-void split_open();
-void split_close();
-void split_redraw();
-int split_keyaction();
+void split_open(void);
+void split_close(void);
+void split_redraw(void);
+int split_keyaction(void);
